From 7c666f2735248aea2b1f47d1e0ffc7f618fe6bcf Mon Sep 17 00:00:00 2001
From: rds <rds>
Date: Tue, 10 Jun 2008 15:03:31 +0000
Subject: [PATCH] zMapURL -> ZMapURL

---
 src/include/ZMap/zmapServerProtocol.h      |  4 +-
 src/include/ZMap/zmapUrl.h                 | 30 +++++++--------
 src/include/ZMap/zmapView.h                |  4 +-
 src/zmapServer/das/dasServer.c             |  6 +--
 src/zmapServer/file/fileServer.c           |  6 +--
 src/zmapServer/zmapServer.c                | 10 ++---
 src/zmapServer/zmapServer.h                |  6 +--
 src/zmapServer/zmapServerProtocolHandler.c |  6 +--
 src/zmapServer/zmapServerPrototype.h       |  4 +-
 src/zmapServer/zmapServer_P.h              |  6 +--
 src/zmapUtils/zmapUrl.c                    | 44 +++++++++++-----------
 src/zmapView/zmapView.c                    |  8 ++--
 src/zmapView/zmapViewUtils.c               |  4 +-
 src/zmapView/zmapView_P.h                  |  4 +-
 14 files changed, 71 insertions(+), 71 deletions(-)

diff --git a/src/include/ZMap/zmapServerProtocol.h b/src/include/ZMap/zmapServerProtocol.h
index 2deb5e9f1..613b0e4db 100755
--- a/src/include/ZMap/zmapServerProtocol.h
+++ b/src/include/ZMap/zmapServerProtocol.h
@@ -30,7 +30,7 @@
  * HISTORY:
  * Last edited: Apr 10 09:19 2008 (rds)
  * Created: Wed Feb  2 11:47:16 2005 (edgrif)
- * CVS info:   $Id: zmapServerProtocol.h,v 1.14 2008-04-10 08:37:17 rds Exp $
+ * CVS info:   $Id: zmapServerProtocol.h,v 1.15 2008-06-10 15:03:46 rds Exp $
  *-------------------------------------------------------------------
  */
 #ifndef ZMAP_PROTOCOL_H
@@ -91,7 +91,7 @@ typedef struct
 {
   ZMapServerReqType type ;
 
-  zMapURL url ;             /* replaces host, port, protocol and allows more info */
+  ZMapURL url ;             /* replaces host, port, protocol and allows more info */
   char *format ;
   int timeout ;
   char *version ;
diff --git a/src/include/ZMap/zmapUrl.h b/src/include/ZMap/zmapUrl.h
index dbab959ca..5cd73a1b8 100755
--- a/src/include/ZMap/zmapUrl.h
+++ b/src/include/ZMap/zmapUrl.h
@@ -53,14 +53,14 @@ typedef enum {
   SCHEME_FILE,
   SCHEME_MYSQL,
   SCHEME_INVALID
-} zMapURL_scheme;
+} ZMapURLScheme;
 
 
 /* Structure containing info on a URL.  */
-typedef struct _zMapURLStruct
+typedef struct _ZMapURLStruct
 {
   char *url;			/* Original URL */
-  zMapURL_scheme scheme;	/* URL scheme */
+  ZMapURLScheme scheme;	/* URL scheme */
   char *protocol;
 
   char *host;			/* Extracted hostname */
@@ -79,30 +79,30 @@ typedef struct _zMapURLStruct
   /* Username and password (unquoted). */
   char *user;
   char *passwd;
-} zMapURLStruct, *zMapURL;
+} ZMapURLStruct, *ZMapURL;
 
 /* Function declarations */
 
 char *url_escape(const char *) ;
 
-zMapURL url_parse(const char *, int *) ;
+ZMapURL url_parse(const char *, int *) ;
 const char *url_error(int) ;
-char *url_full_path(const zMapURL) ;
-void url_set_dir(zMapURL, const char *) ;
-void url_set_file(zMapURL, const char *) ;
-void url_free(zMapURL) ;
+char *url_full_path(const ZMapURL) ;
+void url_set_dir(ZMapURL, const char *) ;
+void url_set_file(ZMapURL, const char *) ;
+void url_free(ZMapURL) ;
 
-zMapURL_scheme url_scheme(const char *) ;
+ZMapURLScheme url_scheme(const char *) ;
 int url_has_scheme(const char *) ;
-int scheme_default_port(zMapURL_scheme) ;
-void scheme_disable(zMapURL_scheme) ;
+int scheme_default_port(ZMapURLScheme) ;
+void scheme_disable(ZMapURLScheme) ;
 
-char *url_string(const zMapURL, int) ;
-char *url_file_name(const zMapURL) ;
+char *url_string(const ZMapURL, int) ;
+char *url_file_name(const ZMapURL) ;
 
 char *uri_merge(const char *, const char *) ;
 
 char *rewrite_shorthand_url(const char *) ;
-int schemes_are_similar_p(zMapURL_scheme a, zMapURL_scheme b) ;
+int schemes_are_similar_p(ZMapURLScheme a, ZMapURLScheme b) ;
 
 #endif /* ZMAPURL_H */
diff --git a/src/include/ZMap/zmapView.h b/src/include/ZMap/zmapView.h
index 89dd31fb7..66f1f2200 100755
--- a/src/include/ZMap/zmapView.h
+++ b/src/include/ZMap/zmapView.h
@@ -31,7 +31,7 @@
  * HISTORY:
  * Last edited: Feb  8 13:45 2008 (edgrif)
  * Created: Thu May 13 14:59:14 2004 (edgrif)
- * CVS info:   $Id: zmapView.h,v 1.49 2008-02-13 16:47:00 edgrif Exp $
+ * CVS info:   $Id: zmapView.h,v 1.50 2008-06-10 15:03:39 rds Exp $
  *-------------------------------------------------------------------
  */
 #ifndef ZMAPVIEW_H
@@ -139,7 +139,7 @@ typedef enum {
 /* A couple of structs to hold data for a view session. */
 typedef struct
 {
-  zMapURL_scheme scheme ;
+  ZMapURLScheme scheme ;
   char *url ;
   char *protocol ;
   char *format ;
diff --git a/src/zmapServer/das/dasServer.c b/src/zmapServer/das/dasServer.c
index 93f35f163..87666cf9b 100755
--- a/src/zmapServer/das/dasServer.c
+++ b/src/zmapServer/das/dasServer.c
@@ -28,7 +28,7 @@
  * HISTORY:
  * Last edited: Feb  7 14:38 2008 (edgrif)
  * Created: Wed Aug  6 15:46:38 2003 (edgrif)
- * CVS info:   $Id: dasServer.c,v 1.30 2008-02-07 14:38:51 edgrif Exp $
+ * CVS info:   $Id: dasServer.c,v 1.31 2008-06-10 15:07:41 rds Exp $
  *-------------------------------------------------------------------
  */
 
@@ -79,7 +79,7 @@ typedef struct
 /* required for server */
 static gboolean globalInit(void) ;
 static gboolean createConnection(void **server_out,
-				 zMapURL url, char *format, 
+				 ZMapURL url, char *format, 
                                  char *version_str, int timeout) ;
 static ZMapServerResponseType openConnection(void *server) ;
 static ZMapServerResponseType getStyles(void *server, GData **styles_out) ;
@@ -196,7 +196,7 @@ static gboolean globalInit(void)
 }
 
 static gboolean createConnection(void **server_out,
-				 zMapURL url, char *format, 
+				 ZMapURL url, char *format, 
                                  char *version_str, int timeout)
 {
   gboolean result = TRUE;
diff --git a/src/zmapServer/file/fileServer.c b/src/zmapServer/file/fileServer.c
index 2a984d4a2..ac2bb5675 100755
--- a/src/zmapServer/file/fileServer.c
+++ b/src/zmapServer/file/fileServer.c
@@ -32,7 +32,7 @@
  * HISTORY:
  * Last edited: Jul 24 11:32 2007 (edgrif)
  * Created: Fri Sep 10 18:29:18 2004 (edgrif)
- * CVS info:   $Id: fileServer.c,v 1.29 2007-07-24 10:33:40 edgrif Exp $
+ * CVS info:   $Id: fileServer.c,v 1.30 2008-06-10 15:07:45 rds Exp $
  *-------------------------------------------------------------------
  */
 
@@ -68,7 +68,7 @@ static gboolean createConnection(void **server_out,
 				 char *host, int port, char *format, char *version_str,
 				 char *userid, char *passwd, int timeout) ;*/
 static gboolean createConnection(void **server_out,
-				 zMapURL url, char *format, 
+				 ZMapURL url, char *format, 
                                  char *version_str, int timeout) ;
 
 static ZMapServerResponseType openConnection(void *server) ;
@@ -142,7 +142,7 @@ static gboolean globalInit(void)
  * 
  *  */
 static gboolean createConnection(void **server_out,
-				 zMapURL url, char *format, 
+				 ZMapURL url, char *format, 
                                  char *version_str, int timeout_unused)
 {
   gboolean result = TRUE ;
diff --git a/src/zmapServer/zmapServer.c b/src/zmapServer/zmapServer.c
index 610174f49..488ccb0f8 100755
--- a/src/zmapServer/zmapServer.c
+++ b/src/zmapServer/zmapServer.c
@@ -26,9 +26,9 @@
  * Description: 
  * Exported functions: See ZMap/zmapServer.h
  * HISTORY:
- * Last edited: Feb  8 15:39 2008 (edgrif)
+ * Last edited: Jun 10 16:07 2008 (rds)
  * Created: Wed Aug  6 15:46:38 2003 (edgrif)
- * CVS info:   $Id: zmapServer.c,v 1.31 2008-02-13 16:48:43 edgrif Exp $
+ * CVS info:   $Id: zmapServer.c,v 1.32 2008-06-10 15:07:09 rds Exp $
  *-------------------------------------------------------------------
  */
 
@@ -46,7 +46,7 @@
 /* This routine must be called before any other server routine and must only be called once,
  * it is the callers responsibility to make sure this is true....
  * NOTE the result is always TRUE at the moment because if we fail on any of these we crash... */
-gboolean zMapServerGlobalInit(zMapURL url, void **server_global_data_out)
+gboolean zMapServerGlobalInit(ZMapURL url, void **server_global_data_out)
 {
   gboolean result = TRUE ;
   ZMapServerFuncs serverfuncs ;
@@ -111,7 +111,7 @@ gboolean zMapServerGlobalInit(zMapURL url, void **server_global_data_out)
 
 
 gboolean zMapServerCreateConnection(ZMapServer *server_out, void *global_data,
-				    zMapURL url, char *format,
+				    ZMapURL url, char *format,
 				    int timeout, char *version_str)
 {
   gboolean result = TRUE ;
@@ -331,7 +331,7 @@ gboolean zMapServerFreeConnection(ZMapServer server)
   gboolean result = TRUE ;
 
   (server->funcs->destroy)(server->server_conn) ;
-  /* Free zMapURL!!!! url_free(server->url)*/
+  /* Free ZMapURL!!!! url_free(server->url)*/
   g_free(server) ;
 
   return result ;
diff --git a/src/zmapServer/zmapServer.h b/src/zmapServer/zmapServer.h
index 63c837449..eda6e74f4 100755
--- a/src/zmapServer/zmapServer.h
+++ b/src/zmapServer/zmapServer.h
@@ -28,7 +28,7 @@
  * HISTORY:
  * Last edited: Feb  8 14:46 2008 (edgrif)
  * Created: Wed Aug  6 15:48:47 2003 (edgrif)
- * CVS info:   $Id: zmapServer.h,v 1.7 2008-02-13 16:48:58 edgrif Exp $
+ * CVS info:   $Id: zmapServer.h,v 1.8 2008-06-10 15:05:08 rds Exp $
  *-------------------------------------------------------------------
  */
 #ifndef ZMAP_SERVER_H
@@ -51,9 +51,9 @@ typedef enum {ZMAP_SERVERRESPONSE_OK,
 /* This routine must be called before any other server routines and must only be called once.
  * It is the callers responsibility to make sure this happens.
  * Provide matching Termination routine ???? */
-gboolean zMapServerGlobalInit(zMapURL url, void **server_global_data_out) ;
+gboolean zMapServerGlobalInit(ZMapURL url, void **server_global_data_out) ;
 gboolean zMapServerCreateConnection(ZMapServer *server_out, void *server_global_data,
-				    zMapURL url,  char *format,
+				    ZMapURL url,  char *format,
 				    int timeout, char *version_str);
 ZMapServerResponseType zMapServerOpenConnection(ZMapServer server) ;
 ZMapServerResponseType zMapServerGetServerInfo(ZMapServer server, char **database_path) ;
diff --git a/src/zmapServer/zmapServerProtocolHandler.c b/src/zmapServer/zmapServerProtocolHandler.c
index c4086c9ec..eb832afa4 100755
--- a/src/zmapServer/zmapServerProtocolHandler.c
+++ b/src/zmapServer/zmapServerProtocolHandler.c
@@ -27,7 +27,7 @@
  * HISTORY:
  * Last edited: Feb  8 15:21 2008 (edgrif)
  * Created: Thu Jan 27 13:17:43 2005 (edgrif)
- * CVS info:   $Id: zmapServerProtocolHandler.c,v 1.25 2008-02-13 16:49:20 edgrif Exp $
+ * CVS info:   $Id: zmapServerProtocolHandler.c,v 1.26 2008-06-10 15:05:20 rds Exp $
  *-------------------------------------------------------------------
  */
 
@@ -70,7 +70,7 @@ typedef struct
 
 
 
-static void protocolGlobalInitFunc(ZMapProtocolInitList protocols, zMapURL url,
+static void protocolGlobalInitFunc(ZMapProtocolInitList protocols, ZMapURL url,
 				   void **global_init_data) ;
 static int findProtocol(gconstpointer list_protocol, gconstpointer protocol) ;
 
@@ -183,7 +183,7 @@ ZMapThreadReturnCode zMapServerTerminateHandler(void **slave_data, char **err_ms
 
 /* Static/global list of protocols and whether their global init/cleanup functions have been
  * called. These are functions that must only be called once. */
-static void protocolGlobalInitFunc(ZMapProtocolInitList protocols, zMapURL url,
+static void protocolGlobalInitFunc(ZMapProtocolInitList protocols, ZMapURL url,
                                    void **global_init_data_out)
 {
   int status = 0;
diff --git a/src/zmapServer/zmapServerPrototype.h b/src/zmapServer/zmapServerPrototype.h
index 85b23a645..4adaf57d0 100755
--- a/src/zmapServer/zmapServerPrototype.h
+++ b/src/zmapServer/zmapServerPrototype.h
@@ -30,7 +30,7 @@
  * HISTORY:
  * Last edited: Feb  8 15:14 2008 (edgrif)
  * Created: Wed Aug  6 15:48:47 2003 (edgrif)
- * CVS info:   $Id: zmapServerPrototype.h,v 1.20 2008-02-13 16:49:39 edgrif Exp $
+ * CVS info:   $Id: zmapServerPrototype.h,v 1.21 2008-06-10 15:05:25 rds Exp $
  *-------------------------------------------------------------------
  */
 #ifndef ZMAP_SERVER_PROTOTYPEP_H
@@ -49,7 +49,7 @@
 typedef gboolean (*ZMapServerGlobalFunc)(void) ;
 
 typedef gboolean (*ZMapServerCreateFunc)(void **server_conn,
-					 zMapURL url, char *format, 
+					 ZMapURL url, char *format, 
                                          char *version_str, int timeout) ;
 
 typedef ZMapServerResponseType (*ZMapServerOpenFunc)(void *server_conn) ;
diff --git a/src/zmapServer/zmapServer_P.h b/src/zmapServer/zmapServer_P.h
index 4a55a5ef9..bc3a27915 100755
--- a/src/zmapServer/zmapServer_P.h
+++ b/src/zmapServer/zmapServer_P.h
@@ -25,9 +25,9 @@
  * Description: 
  * Exported functions: See XXXXXXXXXXXXX.h
  * HISTORY:
- * Last edited: May 15 11:56 2006 (rds)
+ * Last edited: Jun 10 16:05 2008 (rds)
  * Created: Wed Aug  6 15:48:47 2003 (edgrif)
- * CVS info:   $Id: zmapServer_P.h,v 1.10 2006-11-08 09:24:25 edgrif Exp $
+ * CVS info:   $Id: zmapServer_P.h,v 1.11 2008-06-10 15:05:48 rds Exp $
  *-------------------------------------------------------------------
  */
 #ifndef ZMAP_SERVER_P_H
@@ -42,7 +42,7 @@
 /* A connection to a database. */
 typedef struct _ZMapServerStruct
 {
-  zMapURL url ;                 /* Replace the host & protocol ... */
+  ZMapURL url ;                 /* Replace the host & protocol ... */
 
   ZMapServerFuncs funcs ;       /* implementation specific functions
                                    to make the server do the right
diff --git a/src/zmapView/zmapView.c b/src/zmapView/zmapView.c
index 53ca9937c..b8a8d5466 100755
--- a/src/zmapView/zmapView.c
+++ b/src/zmapView/zmapView.c
@@ -27,7 +27,7 @@
  * HISTORY:
  * Last edited: Apr 10 09:25 2008 (rds)
  * Created: Thu May 13 15:28:26 2004 (edgrif)
- * CVS info:   $Id: zmapView.c,v 1.129 2008-04-10 08:36:07 rds Exp $
+ * CVS info:   $Id: zmapView.c,v 1.130 2008-06-10 15:08:04 rds Exp $
  *-------------------------------------------------------------------
  */
 
@@ -75,7 +75,7 @@ static void killConnections(ZMapView zmap_view) ;
 
 
 static ZMapViewConnection createConnection(ZMapView zmap_view,
-					   zMapURL url, char *format,
+					   ZMapURL url, char *format,
 					   int timeout, char *version,
 					   char *styles_file,
 					   char *feature_sets, char *navigator_set_names,
@@ -361,7 +361,7 @@ gboolean zMapViewConnect(ZMapView zmap_view, char *config_str)
 	    {
 	      char *version, *styles_file, *format, *url, *featuresets, *navigatorsets ;
 	      int timeout, url_parse_error ;
-              zMapURL urlObj;
+              ZMapURL urlObj;
 	      gboolean sequence_server, writeback_server, acedb_styles ;
 	      ZMapViewConnection view_con ;
 	      ZMapViewSequence2ServerStruct tmp_seq = {NULL} ;
@@ -1944,7 +1944,7 @@ static void invoke_merge_in_names(gpointer list_data, gpointer user_data)
 
 /* Allocate a connection and send over the request to get the sequence displayed. */
 static ZMapViewConnection createConnection(ZMapView zmap_view,
-					   zMapURL url, char *format,
+					   ZMapURL url, char *format,
 					   int timeout, char *version,
 					   char *styles_file,
 					   char *featuresets_names, char *navigator_set_names,
diff --git a/src/zmapView/zmapViewUtils.c b/src/zmapView/zmapViewUtils.c
index 9e8de200c..d90db9b1d 100755
--- a/src/zmapView/zmapViewUtils.c
+++ b/src/zmapView/zmapViewUtils.c
@@ -29,7 +29,7 @@
  * HISTORY:
  * Last edited: Feb  8 15:36 2008 (edgrif)
  * Created: Mon Sep 20 10:29:15 2004 (edgrif)
- * CVS info:   $Id: zmapViewUtils.c,v 1.8 2008-02-13 16:52:41 edgrif Exp $
+ * CVS info:   $Id: zmapViewUtils.c,v 1.9 2008-06-10 15:08:10 rds Exp $
  *-------------------------------------------------------------------
  */
 
@@ -281,7 +281,7 @@ ZMapViewSession zMapViewSessionGetData(ZMapViewWindow zmap_view_window)
 
 
 
-void zmapViewSessionAddServer(ZMapViewSession session_data, zMapURL url, char *format)
+void zmapViewSessionAddServer(ZMapViewSession session_data, ZMapURL url, char *format)
 {
   ZMapViewSessionServer server_data ;
 
diff --git a/src/zmapView/zmapView_P.h b/src/zmapView/zmapView_P.h
index 5abdd0179..0b68921cf 100755
--- a/src/zmapView/zmapView_P.h
+++ b/src/zmapView/zmapView_P.h
@@ -26,7 +26,7 @@
  * HISTORY:
  * Last edited: Jun  4 18:36 2008 (rds)
  * Created: Thu May 13 15:06:21 2004 (edgrif)
- * CVS info:   $Id: zmapView_P.h,v 1.35 2008-06-04 17:36:26 rds Exp $
+ * CVS info:   $Id: zmapView_P.h,v 1.36 2008-06-10 15:08:15 rds Exp $
  *-------------------------------------------------------------------
  */
 #ifndef ZMAP_VIEW_P_H
@@ -190,7 +190,7 @@ gboolean zmapViewCWHRemoveContextWindow(GHashTable *table, ZMapFeatureContext *c
                                         ZMapWindow window, gboolean *is_only_context);
 void zmapViewCWHDestroy(GHashTable **hash);
 
-void zmapViewSessionAddServer(ZMapViewSession session_data, zMapURL url, char *format) ;
+void zmapViewSessionAddServer(ZMapViewSession session_data, ZMapURL url, char *format) ;
 void zmapViewSessionAddServerInfo(ZMapViewSession session_data, char *database_path) ;
 void zmapViewSessionFreeServer(gpointer data, gpointer user_data_unused) ;
 
diff --git a/src/zmapUtils/zmapUrl.c b/src/zmapUtils/zmapUrl.c
index 58ed49100..deff11774 100755
--- a/src/zmapUtils/zmapUrl.c
+++ b/src/zmapUtils/zmapUrl.c
@@ -138,7 +138,7 @@ static const unsigned char urlchr_table[256] =
 #undef U
 #undef RU
 
-static char* protocol_from_scheme(zMapURL_scheme scheme);
+static char* protocol_from_scheme(ZMapURLScheme scheme);
 
 /* URL-unescape the string S.
 
@@ -416,7 +416,7 @@ reencode_escapes (const char *s)
 /* Returns the scheme type if the scheme is supported, or
    SCHEME_INVALID if not.  */
 
-zMapURL_scheme
+ZMapURLScheme
 url_scheme (const char *url)
 {
   int i;
@@ -426,7 +426,7 @@ url_scheme (const char *url)
 			  strlen (supported_schemes[i].leading_string)))
       {
 	if (supported_schemes[i].enabled)
-	  return (zMapURL_scheme) i;
+	  return (ZMapURLScheme) i;
 	else
 	  return SCHEME_INVALID;
       }
@@ -457,13 +457,13 @@ url_has_scheme (const char *url)
 }
 
 int
-scheme_default_port (zMapURL_scheme scheme)
+scheme_default_port (ZMapURLScheme scheme)
 {
   return supported_schemes[scheme].default_port;
 }
 
 void
-scheme_disable (zMapURL_scheme scheme)
+scheme_disable (ZMapURLScheme scheme)
 {
   supported_schemes[scheme].enabled = 0;
   return ;
@@ -785,7 +785,7 @@ is_valid_ipv6_address (const char *str, const char *end)
 
 /* Parse a URL.
  *******************************************************************************
  * Return a new zMapURL if successful, NULL on error.  In case of
  * error, and if ERROR is not NULL, also set *ERROR to the appropriate
  * error code. 
  *
@@ -810,14 +810,14 @@ is_valid_ipv6_address (const char *str, const char *end)
  *******************************************************************************
  */
 
-zMapURL
+ZMapURL
 url_parse (const char *url, int *error)
 {
-  zMapURL u;
+  ZMapURL u;
   const char *p;
   int path_modified, host_modified;
 
-  zMapURL_scheme scheme;
+  ZMapURLScheme scheme;
 
   const char *uname_b,     *uname_e;
   const char *host_b,      *host_e;
@@ -1012,7 +1012,7 @@ url_parse (const char *url, int *error)
 	}
     }
 
-  u = (zMapURL)xmalloc(sizeof(zMapURLStruct));
+  u = (ZMapURL)xmalloc(sizeof(ZMapURLStruct));
   memset (u, 0, sizeof (*u));
 
   u->scheme = scheme;
@@ -1121,7 +1121,7 @@ split_path (const char *path, char **dir, char **file)
    zero.  */
 
 static int
-full_path_length (const zMapURL url)
+full_path_length (const ZMapURL url)
 {
   int len = 0;
 
@@ -1139,7 +1139,7 @@ full_path_length (const zMapURL url)
 /* Write out the full path. */
 
 static void
-full_path_write (const zMapURL url, char *where)
+full_path_write (const ZMapURL url, char *where)
 {
 #define FROB(el, chr) do {			\
   char *f_el = url->el;				\
@@ -1163,7 +1163,7 @@ full_path_write (const zMapURL url, char *where)
    "/foo/bar?param=value". */
 
 char *
-url_full_path (const zMapURL url)
+url_full_path (const ZMapURL url)
 {
   int length = full_path_length (url);
   char *full_path = (char *)xmalloc(length + 1);
@@ -1210,7 +1210,7 @@ url_escape_dir (const char *dir)
    u->file or u->dir have been changed, typically by the FTP code.  */
 
 static void
-sync_path (zMapURL u)
+sync_path (ZMapURL u)
 {
   char *newpath, *efile, *edir;
 
@@ -1258,7 +1258,7 @@ sync_path (zMapURL u)
    This way we can sync u->path and u->url when they get changed.  */
 
 void
-url_set_dir (zMapURL url, const char *newdir)
+url_set_dir (ZMapURL url, const char *newdir)
 {
   xfree (url->dir);
   url->dir = xstrdup (newdir);
@@ -1266,7 +1266,7 @@ url_set_dir (zMapURL url, const char *newdir)
 }
 
 void
-url_set_file (zMapURL url, const char *newfile)
+url_set_file (ZMapURL url, const char *newfile)
 {
   xfree (url->file);
   url->file = xstrdup (newfile);
@@ -1274,7 +1274,7 @@ url_set_file (zMapURL url, const char *newfile)
 }
 
 void
-url_free (zMapURL url)
+url_free (ZMapURL url)
 {
   xfree (url->host);
   xfree (url->path);
@@ -1501,7 +1501,7 @@ append_uri_pathel (const char *b, const char *e, int escaped_p,
    Each component of the path is quoted for use as file name.  */
 
 static void
-append_dir_structure (const zMapURL u, struct growable *dest)
+append_dir_structure (const ZMapURL u, struct growable *dest)
 {
   char *pathel, *next;
   int cut = opt.cut_dirs;
@@ -1528,7 +1528,7 @@ append_dir_structure (const zMapURL u, struct growable *dest)
    possible.  Does not create directories on the file system.  */
 
 char *
-url_file_name (const zMapURL u)
+url_file_name (const ZMapURL u)
 {
   struct growable fnres;
 
@@ -1930,7 +1930,7 @@ uri_merge (const char *base, const char *link)
    characters in the URL will be quoted.  */
 
 char *
-url_string (const zMapURL url, int hide_password)
+url_string (const ZMapURL url, int hide_password)
 {
   int size;
   char *result, *p;
@@ -2020,7 +2020,7 @@ url_string (const zMapURL url, int hide_password)
    are also similar if one is http (SCHEME_HTTP) and the other is https
    (SCHEME_HTTPS).  */
 int
-schemes_are_similar_p (zMapURL_scheme a, zMapURL_scheme b)
+schemes_are_similar_p (ZMapURLScheme a, ZMapURLScheme b)
 {
   if (a == b)
     return 1;
@@ -2033,7 +2033,7 @@ schemes_are_similar_p (zMapURL_scheme a, zMapURL_scheme b)
 }
 
 static char *
-protocol_from_scheme(zMapURL_scheme scheme)
+protocol_from_scheme(ZMapURLScheme scheme)
 {
   char *tmp = NULL;
   tmp = supported_schemes[scheme].leading_string;
@@ -785,7 +785,7 @@ is_valid_ipv6_address (const char *str, const char *end)
 /* Parse a URL.
  *******************************************************************************
- * Return a new zMapURL if successful, NULL on error.  In case of
+ * Return a new ZMapURL if successful, NULL on error.  In case of
  * error, and if ERROR is not NULL, also set *ERROR to the appropriate
  * error code. 
-- 
GitLab